@@ -34,6 +34,10 @@ class LogSettings:
         result = messages.message["undetermined"]
 
         try:
+            if self.log_config is None:
+                print(module, "log_config is None, i.e. an empty value was provided for the log configuration file.")
+                return messages.message["log_config_is_none"]
+
             with open(self.log_config) as config:
                 data = json.load(config)
                 self.log_directory = data["log_directory"]
@@ -43,18 +47,23 @@ class LogSettings:
                     self.configured_log_level = data["log_level"]
                 else:
                     self.configured_log_level = "DEBUG"
+                    print("module, Missing log_level. Set to default=\"DEBUG\"")
                 self.log_level = self.determine_log_level(self.configured_log_level)
                 if "azure_monitor_config" in data:
                     self.azure_monitor_config = data["azure_monitor_config"]
                 if "azure_monitor_requests" in data:
                     if data["azure_monitor_requests"] == "True":
                         self.azure_monitor_requests = True
+                        print(module, "azure_monitor_requests has been set to True")
                     elif data["azure_monitor_requests"] == "False":
                         self.azure_monitor_requests = False
+                        print(module, "azure_monitor_requests has been set to False")
                     else:
                         print(module, "Incorrect config value >" + data["azure_monitor_requests"]
                               + "< for azure_monitor_requests. Must be True or False")
                         self.azure_monitor_requests = False
+                else:
+                    print(module, "azure_monitor_requests not found. Not logging to Azure.")
 
             result = messages.message["ok"]
         except FileNotFoundError:
@@ -64,23 +73,30 @@ class LogSettings:
         return result
 
     def determine_log_level(self, configured_log_level):
+        module = __name__ + ".determine_log_level"
         if configured_log_level == "VERBOSE":
             self.log_level = self.VERBOSE
+            print(module, "Log level has been set to VERBOSE.")
             return self.log_level
         elif configured_log_level == logging.getLevelName(logging.DEBUG):
             self.log_level = self.DEBUG
+            print(module, "Log level has been set to DEBUG.")
             return self.log_level
         elif configured_log_level == logging.getLevelName(logging.INFO):
             self.log_level = self.INFO
+            print(module, "Log level has been set to INFO.")
             return self.log_level
         elif configured_log_level == logging.getLevelName(logging.WARNING):
             self.log_level = self.WARNING
+            print(module, "Log level has been set to WARNING.")
             return self.log_level
         elif configured_log_level == logging.getLevelName(logging.ERROR):
             self.log_level = self.ERROR
+            print(module, "Log level has been set to ERROR.")
             return self.log_level
         elif configured_log_level == logging.getLevelName(logging.FATAL):
             self.log_level = self.FATAL
+            print(module, "Log level has been set to FATAL.")
             return self.log_level
         else:
             print(f"invalid log level >{configured_log_level}< in config.json. Defaulting to DEBUG")
